@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2009-2010 B.A.T.M.A.N. contributors:
  *
  * Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -197,7 +197,7 @@ static int routing_table_new(char *orig, char *next_hop, char *old_next_hop, cha
 	int i, j;
 
 	if (!curr_bat_node) {
-		fprintf(stderr, "Routing table change without preceeding OGM - skipping");
+		fprintf(stderr, "Routing table change without preceding OGM - skipping");
 		goto err;
 	}
 
@@ -225,7 +225,7 @@ static int routing_table_new(char *orig, char *next_hop, char *old_next_hop, cha
 		goto err;
 
 	if (list_empty(&orig_event->event_list)) {
-		fprintf(stderr, "Routing table change without any preceeding OGM of that originator - skipping");
+		fprintf(stderr, "Routing table change without any preceding OGM of that originator - skipping");
 		goto err;
 	}
 
@@ -1513,7 +1513,7 @@ int bisect(int argc, char **argv)
 	node_hash = hash_new(64, compare_name, choose_name);
 
 	if (!node_hash) {
-		printf("Error - couldn't not create node hash table\n");
+		printf("Error - could not create node hash table\n");
 		goto err;
 	}
 
