@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2007-2009 B.A.T.M.A.N. contributors:
+/*
+ * Copyright (C) 2007-2010 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <a.langer@q-dsl.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -25,6 +25,8 @@
 
 
 #define ETH_STR_LEN 17
+#define BATMAN_ADV_TAG "batman-adv:"
+#define SEARCH_ARGS_TAG "commands:"
 
 /* return time delta from start to end in milliseconds */
 void start_timer(void);
@@ -32,8 +34,12 @@ double end_timer(void);
 char *ether_ntoa_long(const struct ether_addr *addr);
 char *get_name_by_macaddr(struct ether_addr *mac_addr, int read_opt);
 char *get_name_by_macstr(char *mac_str, int read_opt);
-int read_proc_file(char *path, int read_opt);
-int write_proc_file(char *path, char *value);
+int read_file(char *dir, char *path, int read_opt);
+int write_file(char *dir, char *fname, char *arg1, char *arg2);
+int check_sys_dir(char *dir);
+char *strchr_anyof(const char *s, const char *n);
+
+extern char *line_ptr;
 
 enum {
 	SINGLE_READ = 0x00,
@@ -41,4 +47,7 @@ enum {
 	CLR_CONT_READ = 0x02,
 	USE_BAT_HOSTS = 0x04,
 	LOG_MODE = 0x08,
+	USE_READ_BUFF = 0x10,
+	SEARCH_ARGS = 0x20,
+	SILENCE_ERRORS = 0x40,
 };
