@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2007-2009 B.A.T.M.A.N. contributors:
+/*
+ * Copyright (C) 2007-2010 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <a.langer@q-dsl.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -21,7 +21,6 @@
 
 
 
-#define SOURCE_VERSION "0.2"  /*put exactly one distinct word inside the string like "0.3-pre-alpha" or "0.3-rc1" or "0.3" */
+#define SOURCE_VERSION "2010.0.0"
 
 #define BAT_DEVICE "/dev/batman-adv"
-#define PROC_ROOT_PATH "/proc/net/batman-adv/"
