@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2007-2009 B.A.T.M.A.N. contributors:
+/*
+ * Copyright (C) 2007-2010 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <a.langer@q-dsl.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -37,4 +37,9 @@ struct dump_if {
 	struct sockaddr_ll addr;
 };
 
+struct vlanhdr {
+	unsigned short vid;
+	u_int16_t ether_type;
+} __attribute__ ((packed));
+
 int tcpdump(int argc, char **argv);
